@@ -85,9 +85,6 @@ class Recipe(Scripts):
         )
         options['bin-directory'] = buildout['buildout']['bin-directory']
 
-        if 'initialization' not in options:
-            options['initialization'] = ''
-
         if 'scripts' in options:
             if options['scripts'] == '':
                 options['scripts'] = ''  # suppress script generation.
@@ -104,6 +101,10 @@ class Recipe(Scripts):
         else:
             self._relative_paths = ''
 
+        if 'initialization' not in options:
+            options['initialization'] = ''
+        options['initialization'] = options['initialization'] % options
+
         self._include_site_packages = options.get(
             'include-site-packages',
             buildout['buildout'].get('include-site-packages', 'false')
@@ -230,11 +231,11 @@ class Recipe(Scripts):
             http_force_connection_close = (
                 http_force_connection_close_template
                 % http_force_connection_close)
-        http_fast_listen = options.get('http-fast-listen', None)
-        if http_fast_listen is None:
-            http_fast_listen = ''
+        http_fast_listen = options.get('http-fast-listen', 'on') or ''
+        if http_fast_listen.lower() in ("on", "true"):
+            http_fast_listen = http_fast_listen_template % 'on'
         else:
-            http_fast_listen = http_fast_listen_template % http_fast_listen
+            http_fast_listen = http_fast_listen_template % 'off'
         http_address = options.get('http-address', '8080')
         if http_address:
             http_address = http_server_template % dict(
@@ -295,7 +296,7 @@ class Recipe(Scripts):
             chameleon_cache = 'CHAMELEON_CACHE {}'.format(chameleon_cache)
             if environment_vars and '\n' in environment_vars:
                 # default case
-                environment_vars += '\n'.format(chameleon_cache)
+                environment_vars += '\n{}'.format(chameleon_cache)
             elif environment_vars:
                 # handle case of all vars in one line
                 environment_vars += ' {}'.format(chameleon_cache)
@@ -475,13 +476,25 @@ class Recipe(Scripts):
                 # All generic RelStorage options have a dash in their name,
                 # except the "name" option. Other options are
                 # database-specific.
+                if name == 'data-dir':  # sqlite3
+                    return False
                 return '-' in name or name == 'name'
 
+            db_opts = '\n'.join(' ' * 12 + ' '.join((k, v))
+                                for k, v in rel_storage.items()
+                                if not is_rs_option(k))
+            if type_ == 'sqlite3':
+                pragmas = [k for k in rel_storage if k.startswith('pragmas-')]
+                if pragmas:
+                    db_opts += '\n' + ' ' * 12 + '<pragmas>\n'
+                    for k in sorted(pragmas):
+                        db_opts += ' ' * 16 + \
+                            ' '.join((k[8:], rel_storage[k])) + '\n'
+                        del rel_storage[k]
+                    db_opts += ' ' * 12 + '</pragmas>\n'
             opts = dict(
                 type=type_,
-                db_opts='\n'.join(' ' * 12 + ' '.join((k, v))
-                                  for k, v in rel_storage.items()
-                                  if not is_rs_option(k)),
+                db_opts=db_opts,
                 rs_opts='\n'.join(' ' * 8 + ' '.join((k, v))
                                   for k, v in rel_storage.items()
                                   if is_rs_option(k)),
@@ -704,9 +717,9 @@ class Recipe(Scripts):
             enable_products=enable_products,
             zope_conf_additional=zope_conf_additional,)
 
-        zope_conf = '\n'.join([l
-                               for l in zope_conf.splitlines()
-                               if l.rstrip()])
+        zope_conf = "\n".join(
+            [line for line in zope_conf.splitlines() if line.rstrip()]
+        )
         zope_conf_path = os.path.join(location, 'etc', 'zope.conf')
         with open(zope_conf_path, 'w') as f:
             f.write(zope_conf)
@@ -715,10 +728,14 @@ class Recipe(Scripts):
         options = self.options
         wsgi_ini_path = os.path.join(options['location'], 'etc', 'wsgi.ini')
         listen = options.get('http-address', '0.0.0.0:8080')
-        fast = 'fast-' if options.get('http-fast-listen') is not None else ''
-        if ':' not in listen:
-            listen = '0.0.0.0:{}'.format(listen)
-
+        fast_listen = options.get('http-fast-listen', 'on') or ''
+        fast = 'fast-' if fast_listen.lower() in ('on', 'true') else ''
+        listen = ' '.join(
+            [
+                '0.0.0.0:{}'.format(part) if ':' not in part else part
+                for part in listen.split()
+            ]
+        )
         base_dir = self.buildout['buildout']['directory']
         var_dir = options.get('var', os.path.join(base_dir, 'var'))
         default_eventlog = os.path.sep.join(
@@ -729,7 +746,7 @@ class Recipe(Scripts):
         eventlog_kwargs = options.get('event-log-kwargs', '{}')
         eventlog_args = options.get('event-log-args')
         if not eventlog_args:
-            eventlog_args = "('{}', 'a')".format(eventlog_name)
+            eventlog_args = "(r'{}', 'a')".format(eventlog_name)
         else:
             eventlog_args = eventlog_args.format(eventlog_name)
 
@@ -753,7 +770,7 @@ class Recipe(Scripts):
         accesslog_kwargs = options.get('access-log-kwargs', '{}')
         accesslog_args = options.get('access-log-args')
         if not accesslog_args:
-            accesslog_args = "('{}', 'a')".format(accesslog_name)
+            accesslog_args = "(r'{}', 'a')".format(accesslog_name)
         else:
             accesslog_args = accesslog_args.format(accesslog_name)
 
@@ -772,32 +789,41 @@ class Recipe(Scripts):
         sentry_event_level = options.get('sentry_event_level', 'ERROR')
         sentry_ignore = options.get('sentry_ignore', '')
 
+        clear_untrusted_proxy_headers = options.get(
+            'clear-untrusted-proxy-headers', 'false'
+        )
+
         pipeline.append('zope')
         pipeline = '\n    '.join(pipeline)
         wsgi_options = {
-            'location': options['location'],
-            'http_address': listen,
-            'threads': options.get('threads', 4),
-            'fast-listen': fast,
-            'root_handlers': root_handlers,
-            'accesslog_name': accesslog_name,
-            'accesslog_handler': accesslog_handler,
-            'accesslog_level': accesslog_level,
             'accesslog_args': accesslog_args,
+            'accesslog_handler': accesslog_handler,
             'accesslog_kwargs': accesslog_kwargs,
+            'accesslog_level': accesslog_level,
+            'accesslog_name': accesslog_name,
+            'clear_untrusted_proxy_headers': clear_untrusted_proxy_headers,
             'event_handlers': event_handlers,
-            'eventlog_name': eventlog_name,
-            'eventlog_handler': eventlog_handler,
-            'eventlog_level': eventlog_level,
             'eventlog_args': eventlog_args,
+            'eventlog_handler': eventlog_handler,
             'eventlog_kwargs': eventlog_kwargs,
+            'eventlog_level': eventlog_level,
+            'eventlog_name': eventlog_name,
             'fast-listen': fast,
             'http_address': listen,
+            # todo: make this configurable
+            'listen_ip': '127.0.0.1',
+            'listen_port': '8080',
+            # /todo
+            'location': options['location'],
+            'max_request_body_size': options.get(
+                'max-request-body-size', 1073741824),
             'pipeline': pipeline,
+            'root_handlers': root_handlers,
             'sentry_dsn': sentry_dsn,
-            'sentry_level': sentry_level,
             'sentry_event_level': sentry_event_level,
             'sentry_ignore': sentry_ignore,
+            'sentry_level': sentry_level,
+            'threads': options.get('threads', 4),
         }
 
         global wsgi_ini_template
@@ -809,11 +835,21 @@ class Recipe(Scripts):
             except IOError:
                 raise
 
+        # generate a different [server:main] - useful for Windows
+        wsgi_server_main_template = wsgi_server_main_templates.get(
+            sys.platform,
+            wsgi_server_main_templates['default']
+        )
+        wsgi_options['server_main'] = wsgi_server_main_template % wsgi_options
+
         wsgi_ini = wsgi_ini_template % wsgi_options
         with open(wsgi_ini_path, 'w') as f:
             f.write(wsgi_ini)
 
     def install_scripts(self):
+        if IS_WIN:
+            # instance scripts are usung zdaemon, which are Unix only
+            return {}
         options = self.options
         location = options['location']
 
@@ -888,14 +924,13 @@ class Recipe(Scripts):
                 script_arguments=script_arguments,
             )
         else:
-            initialization = options['initialization'] % options
             return zc.buildout.easy_install.scripts(
                 dest=dest,
                 reqs=reqs,
                 working_set=working_set,
                 executable=options['executable'],
                 extra_paths=extra_paths,
-                initialization=initialization,
+                initialization=options['initialization'],
                 arguments=script_arguments,
                 interpreter=interpreter,
                 relative_paths=self._relative_paths,)
@@ -1334,12 +1369,26 @@ additional_zcml_template = """\
 </configure>
 """
 
-wsgi_ini_template = """\
-[server:main]
+wsgi_server_main_templates = {}
+wsgi_server_main_templates['default'] = """\
 paste.server_factory = plone.recipe.zope2instance:main
 use = egg:plone.recipe.zope2instance#main
 %(fast-listen)slisten = %(http_address)s
 threads = %(threads)s
+clear_untrusted_proxy_headers = %(clear_untrusted_proxy_headers)s
+max_request_body_size = %(max_request_body_size)s
+"""
+
+wsgi_server_main_templates['win32'] = """\
+use = egg:waitress#main
+host = %(listen_ip)s
+port = %(listen_port)s
+clear_untrusted_proxy_headers = %(clear_untrusted_proxy_headers)s
+"""
+
+wsgi_ini_template = """\
+[server:main]
+%(server_main)s
 
 [app:zope]
 use = egg:Zope#main
